Struct wasmtime_fiber::FiberStack[][src]

pub struct FiberStack(_);
Represents an execution stack to use for a fiber.

Implementations

impl FiberStack[src]

pub fn new(size: usize) -> Result<Self>[src]

Creates a new fiber stack of the given size.

pub unsafe fn from_top_ptr(top: *mut u8) -> Result<Self>[src]

Creates a new fiber stack with the given pointer to the top of the stack.

Safety

This is unsafe because there is no validation of the given stack pointer.

The caller must properly allocate the stack space with a guard page and make the pages accessible for correct behavior.

pub fn top(&self) -> Option<*mut u8>[src]

Gets the top of the stack.

Returns None if the platform does not support getting the top of the stack.